import component from './component';

document.body.appendChild(component());
